@@ -3,10 +3,10 @@
 #   density.circular function                               #
 #   Author: Claudio Agostinelli                             #
 #   Email: claudio@unive.it                                 #
-#   date: July, 02, 2011                                    #
-#   Copyright (C) 2011 Claudio Agostinelli                  #
+#   date: February, 14, 2013                                #
+#   Copyright (C) 2013 Claudio Agostinelli                  #
 #                                                           #
-#   Version 0.3                                             #
+#   Version 0.3-1                                           #
 #                                                           #
 #############################################################
 
@@ -116,7 +116,7 @@ density.circular <- function(x, z=NULL, bw, adjust = 1, type = c("K", "L"), kern
 DensityCircularRad <- function(x, z, bw, kernel, K=NULL, min.k=10) {
    nx <- length(x)
    if (kernel=="vonmises") {
-       y <- sapply(z, DvonmisesRad, mu=x, kappa=bw)
+       y <- sapply(z, DvonmisesRad, mu=x, kappa=bw, log=FALSE)
    } else if (kernel=="wrappednormal") {
        rho <- exp(-bw^2/2)
        y <- sapply(z, DwrappednormalRad, mu=x, rho=rho, K=K, min.k=min.k)
@@ -132,10 +132,10 @@ DensityCircularRad <- function(x, z, bw, kernel, K=NULL, min.k=10) {
 #   plot.density.circular function                          #
 #   Author: Claudio Agostinelli                             #
 #   Email: claudio@unive.it                                 #
-#   Date: July, 5, 2011                                     #
+#   Date: July, 22, 2011                                     #
 #   Copyright (C) 2011 Claudio Agostinelli                  #
 #                                                           #
-#   Version 0.5-1                                           #
+#   Version 0.5-12                                           #
 #                                                           #
 #############################################################
 
@@ -200,7 +200,7 @@ plot.density.circular <- function(x, main = NULL, sub=NULL, xlab = NULL, ylab ="
       x$x <- x$x[xorder]
       x$y <- x$y[xorder]
       
-      plot.default(x, type = type, xlim=xlim, ylim=ylim, main = main, xlab = xlab, ylab = ylab, ...)
+      plot.default(x, type = type, xlim=xlim, ylim=ylim, main=main, xlab=xlab, ylab=ylab, axes=axes, ...)
       if (zero.line) 
          abline(h = 0, lwd = 0.2, col = "gray")
       if (points.plot)
